/***************************************************************************
                           job_removecustomquery.h
                             -------------------
    begin                : 2005-04-19
    copyright            : (C) 2005 by Markus Kalkbrenner
    email                : mkalkbrenner@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the license, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef JOB_REMOVECUSTOMQUERY_H
#define JOB_REMOVECUSTOMQUERY_H

#include "prokyon.h"

#include "jobbase.h"

class Job_RemoveCustomQuery : public JobBase  {
public:
    Job_RemoveCustomQuery(QString _name);

    int type() {
        return JOB_REMOVE_CUSTOM_QUERY;
    }

    void run();

    ~Job_RemoveCustomQuery();

private:
    QString name;
};

#endif
